# About

## About OneTool

Discover the story behind OneTool — why it was built, how it works, and what makes it different — including how it helps you avoid the MCP “Tool Tax” and reduce Context Bloat as your toolset grows.
[:octicons-arrow-right-24: Read more](about-onetool.md)

## About Me

I am a technology leader, engineering manager and solutions architect with 25+ years’ experience developing, maintaining, operating and scaling large complex systems, now stepping out of the architecture ivory tower and returning to my development roots.
[:octicons-arrow-right-24: GitHub](https://github.com/gavinlas)

## Links

- [GitHub Repository](https://github.com/beycom/onetool-mcp)
- [PyPI Package](https://pypi.org/project/onetool-mcp/)
